%******************
% Main code for estimates in Tables 1-4 of
% "Assymmetry, Complementarities, and State Dependence in Federal Reserve
% Forecasts"
% Caunedo, DiCecio, Komunjer, Owyang 2018
% 
%******************

clear
global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 ERROR_SERIES2 INSTRUMENTS2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUTS
% Old Own Data data_RD_final.xlsx
% Updated Own Data data_final_upd.xlsx
% New Data Philly nowcast data_philly.xlsx
% New Data Philly, 'x'=1stp,2stp and 4stp  data_philly_'x'.xlsx
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUT
% results.A saves xx1 from the estimation: alpha and J_test
% results.B saves xx2 from the estimation: wald test, p-value f/main sample
% and wald test, p-value f/break samples
% std_err.s  records the std. errors of the assimmetry parameters
% res_smp record J test for subsamples as required.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Paths to locate input files

addpath('C:\Users\julietaadmin\Dropbox\Forecast\Final Submission-2018\Replication_CDKO\data\'); 
addpath('C:\Users\julietaadmin\Dropbox\Forecast\Final Submission-2018\Replication_CDKO\mfiles\'); 
savepath='C:\Users\julietaadmin\Dropbox\Forecast\Final Submission-2018\Replication_CDKO\output_mat\';
%% parameters
P = 2;
for iter=3:3
p = P;
%% Loads Data
data=iter;
%% Own computer
  if data==1
  y = xlsread('data_RD_final.xlsx','Data');
elseif data==2
  y = xlsread('data_RD_final_upd.xlsx','Data');
elseif data==3
 y = xlsread('data_philly.xlsx','Data');
elseif data==4
  y = xlsread('data_philly_1stp.xlsx','Data');
elseif data==5
  y = xlsread('data_philly_2stp.xlsx','Data');
elseif data==6
  y = xlsread('data_philly_4stp.xlsx','Data');
elseif data==7
  y = xlsread('data_philly_1st_release.xlsx','Data');
  end

fin=size(y,1);

%% Initializes vectors 
dummies = y(1:fin,14:16);

fDATA.e = [y(1:fin,3) , y(1:fin,7), y(1:fin,12)];
fDATA.r = [y(1:fin,1) , y(1:fin,5), y(1:fin,10)];

%%%%%%%%%%%%%%%%%%
% with constant
%X = [ones(fin,1), y(1:fin,4) , y(1:fin,13), y(1:fin,8)];
%%%%%%%%%%%%%%%%%%
% without constant
X = [y(1:fin,4) , y(1:fin,8), y(1:fin,13)];

%%%%%%%%%%%%%%%%%%
% Clean up data for NaN entries
while max(isnan(fDATA.e))>0
    
indnan=find(isnan(fDATA.e(:,1)),1)

if indnan==1
    X=X(indnan+1:end,:);
    fDATA.e=fDATA.e(indnan+1:end,:);
    fDATA.r=fDATA.r(indnan+1:end,:);
    dummies=dummies(indnan+1:end,:);

else
    X=[X(1:indnan-1,:);X(indnan+1:end,:)];
fDATA.e=[fDATA.e(1:indnan-1,:);fDATA.e(indnan+1:end,:)];
fDATA.r=[fDATA.r(1:indnan-1,:);fDATA.r(indnan+1:end,:)];
dummies=[dummies(1:indnan-1,:);dummies(indnan+1:end,:)];
end
end

while max(isnan(X(:,2)))>0
    
indnan=find(isnan(X(:,2)),1);

if indnan==1
    X=X(indnan+1:end,:);
    fDATA.e=fDATA.e(indnan+1:end,:);
    fDATA.r=fDATA.r(indnan+1:end,:);
    dummies=dummies(indnan+1:end,:);

else
     X=[X(1:indnan-1,:);X(indnan+1:end,:)];
fDATA.e=[fDATA.e(1:indnan-1,:);fDATA.e(indnan+1:end,:)];
fDATA.r=[fDATA.r(1:indnan-1,:);fDATA.r(indnan+1:end,:)];
dummies=[dummies(1:indnan-1,:);dummies(indnan+1:end,:)];
end

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%5
% Benchmark series
ERROR_SERIES=fDATA.e; 
REALIZED_SERIES=fDATA.r;
INSTRUMENTS=X; 

T=size(ERROR_SERIES,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set Up Breaks

%% Full Sample
disp('full data ')


[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 std_err(1).s=xx2;

  gamful=elasticities(ERROR_SERIES,p,xx1.alfa_2);
 
    gamafull=[gamful(1,2) gamful(1,3) gamful(2,3)];



%****************
% Great Moderation

BRT=find(dummies(:,3),1)-1;

PiSB=BRT/T;
ERROR_SERIES1=ERROR_SERIES(1:BRT,:);
ERROR_SERIES2=ERROR_SERIES(BRT+1:T,:);
INSTRUMENTS1=INSTRUMENTS(1:BRT,:);
INSTRUMENTS2=INSTRUMENTS(BRT+1:T,:);
REALIZED_SERIES1=REALIZED_SERIES(1:BRT,:);
REALIZED_SERIES2=REALIZED_SERIES(BRT+1:T,:);

disp('Great Moderation')
[xx1 xx2] = gmm_multi3ikTest_elast(ERROR_SERIES,INSTRUMENTS,P);
                results(1).A = xx1;
                results(1).B = xx2;
                
  

     gamapre=elasticities(ERROR_SERIES1,p,xx1.alfa_brk1);
                gamapost=elasticities(ERROR_SERIES2,p,xx1.alfa_brk2);
                gama(1).pre=[gamapre(1,2) gamapre(1,3) gamapre(2,3)];
                gama(1).post=[gamapost(1,2) gamapost(1,3) gamapost(2,3)];
                
           
                deltaf(1).full=partial_effects(ERROR_SERIES,REALIZED_SERIES,p,xx1.alfa_2);

      deltaf(1).pre=partial_effects(ERROR_SERIES1,REALIZED_SERIES1,p,xx1.alfa_brk1);
      deltaf(1).post=partial_effects(ERROR_SERIES2,REALIZED_SERIES2,p,xx1.alfa_brk2);
 
 clearvars -global -except ERROR_SERIES INSTRUMENTS REALIZED_SERIES P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 

%***************
% Volcker

BRT=find(dummies(:,2),1)-1;  
PiSB=BRT/T;
ERROR_SERIES1=ERROR_SERIES(1:BRT,:);
ERROR_SERIES2=ERROR_SERIES(BRT+1:T,:);
INSTRUMENTS1=INSTRUMENTS(1:BRT,:);
INSTRUMENTS2=INSTRUMENTS(BRT+1:T,:);
REALIZED_SERIES1=REALIZED_SERIES(1:BRT,:);
REALIZED_SERIES2=REALIZED_SERIES(BRT+1:T,:);

    disp('Volcker break')

  [xx1 xx2] = gmm_multi3ikTest_elast(ERROR_SERIES,INSTRUMENTS,P);
                results(2).A = xx1;
                results(2).B = xx2;
                gamapre=elasticities(ERROR_SERIES1,p,xx1.alfa_brk1);
                gamapost=elasticities(ERROR_SERIES2,p,xx1.alfa_brk2);
                gama(2).pre=[gamapre(1,2) gamapre(1,3) gamapre(2,3)];
                gama(2).post=[gamapost(1,2) gamapost(1,3) gamapost(2,3)];
                     deltaf(2).pre=partial_effects(ERROR_SERIES1,REALIZED_SERIES1,p,xx1.alfa_brk1);
      deltaf(2).post=partial_effects(ERROR_SERIES2,REALIZED_SERIES2,p,xx1.alfa_brk2);


  clearvars -global -except ERROR_SERIES INSTRUMENTS REALIZED_SERIES P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 
%****************
% NBER dates

ERROR_SERIES1=fDATA.e(dummies(:,1)~=1,:);
ERROR_SERIES2=fDATA.e(dummies(:,1)==1,:);
INSTRUMENTS1=X(dummies(:,1)~=1,:);
INSTRUMENTS2=X(dummies(:,1)==1,:);
REALIZED_SERIES1=REALIZED_SERIES(dummies(:,1)~=1,:);
REALIZED_SERIES2=REALIZED_SERIES(dummies(:,1)==1,:);

BRT=length(ERROR_SERIES1);
PiSB=BRT/T;

disp('NBER Breaks')

  [xx1 xx2] = gmm_multi3ikTest_elast(ERROR_SERIES,INSTRUMENTS,P);
                results(3).A = xx1;
                results(3).B = xx2;
                
                  gamapre=elasticities(ERROR_SERIES1,p,xx1.alfa_brk1);
                gamapost=elasticities(ERROR_SERIES2,p,xx1.alfa_brk2);
                gama(3).pre=[gamapre(1,2) gamapre(1,3) gamapre(2,3)];
                gama(3).post=[gamapost(1,2) gamapost(1,3) gamapost(2,3)];
      deltaf(3).pre=partial_effects(ERROR_SERIES1,REALIZED_SERIES1,p,xx1.alfa_brk1);
      deltaf(3).post=partial_effects(ERROR_SERIES2,REALIZED_SERIES2,p,xx1.alfa_brk2);

 clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
              
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Expansions only

disp ('Expansions Only')

ERROR_SERIES=fDATA.e(dummies(:,1)~=1,:);
INSTRUMENTS=X(dummies(:,1)~=1,:);
REALIZED_SERIES=fDATA.r(dummies(:,1)~=1,:);


dummies_exp=dummies(dummies(:,1)~=1,:);

T=size(ERROR_SERIES,1);

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 std_err(2).s=xx2;
 
%****************
% Great Moderation

BRT=find(dummies_exp(:,3),1)-1;  %NEED THE CORRECT BRT
PiSB=BRT/T;

ERROR_SERIES1=ERROR_SERIES(1:BRT,:);
ERROR_SERIES2=ERROR_SERIES(BRT+1:T,:);
INSTRUMENTS1=INSTRUMENTS(1:BRT,:);
INSTRUMENTS2=INSTRUMENTS(BRT+1:T,:);
REALIZED_SERIES1=REALIZED_SERIES(1:BRT,:);
REALIZED_SERIES2=REALIZED_SERIES(BRT+1:T,:);



    disp('Great Moderation')

   
  [xx1 xx2] = gmm_multi3ikTest_elast(ERROR_SERIES,INSTRUMENTS,P);
                results(4).A = xx1;
                results(4).B = xx2;
        gamapre=elasticities(ERROR_SERIES1,p,xx1.alfa_brk1);
                gamapost=elasticities(ERROR_SERIES2,p,xx1.alfa_brk2);
                gama(4).pre=[gamapre(1,2) gamapre(1,3) gamapre(2,3)];
                gama(4).post=[gamapost(1,2) gamapost(1,3) gamapost(2,3)]; 
                      deltaf(4).pre=partial_effects(ERROR_SERIES1,REALIZED_SERIES1,p,xx1.alfa_brk1);
      deltaf(4).post=partial_effects(ERROR_SERIES2,REALIZED_SERIES2,p,xx1.alfa_brk2);
      
  clearvars -global -except ERROR_SERIES INSTRUMENTS REALIZED_SERIES P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
        
%****************
% Volcker
BRT=find(dummies_exp(:,2),1)-1;  %NEED THE CORRECT BRT
PiSB=BRT/T;
ERROR_SERIES1=ERROR_SERIES(1:BRT,:);
ERROR_SERIES2=ERROR_SERIES(BRT+1:T,:);
INSTRUMENTS1=INSTRUMENTS(1:BRT,:);
INSTRUMENTS2=INSTRUMENTS(BRT+1:T,:);
REALIZED_SERIES1=REALIZED_SERIES(1:BRT,:);
REALIZED_SERIES2=REALIZED_SERIES(BRT+1:T,:);

    disp('Volcker break')

  [xx1 xx2] = gmm_multi3ikTest_elast(ERROR_SERIES,INSTRUMENTS,P);
                results(5).A = xx1;
                results(5).B = xx2;
                
                  gamapre=elasticities(ERROR_SERIES1,p,xx1.alfa_brk1);
                gamapost=elasticities(ERROR_SERIES2,p,xx1.alfa_brk2);
                gama(5).pre=[gamapre(1,2) gamapre(1,3) gamapre(2,3)];
                gama(5).post=[gamapost(1,2) gamapost(1,3) gamapost(2,3)];
                      deltaf(5).pre=partial_effects(ERROR_SERIES1,REALIZED_SERIES1,p,xx1.alfa_brk1);
      deltaf(5).post=partial_effects(ERROR_SERIES2,REALIZED_SERIES2,p,xx1.alfa_brk2);
 clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
             
%% Recessions only


ERROR_SERIES=fDATA.e(dummies(:,1)==1,:);
INSTRUMENTS=X(dummies(:,1)==1,:);
REALIZED_SERIES=fDATA.r(dummies(:,1)==1,:);
dummies_rec=dummies(dummies(:,1)==1,:);

T=size(ERROR_SERIES,1);
disp ('Recessions Only')

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 std_err(3).s=xx2;
%****************
% Great Moderation

BRT=find(dummies_rec(:,3),1)-1;  %NEED THE CORRECT BRT
PiSB=BRT/T;
ERROR_SERIES1=ERROR_SERIES(1:BRT,:);
ERROR_SERIES2=ERROR_SERIES(BRT+1:T,:);
INSTRUMENTS1=INSTRUMENTS(1:BRT,:);
INSTRUMENTS2=INSTRUMENTS(BRT+1:T,:);
REALIZED_SERIES1=REALIZED_SERIES(1:BRT,:);
REALIZED_SERIES2=REALIZED_SERIES(BRT+1:T,:);

    disp('Great Moderation')

   
  [xx1 xx2] = gmm_multi3ikTest_elast(ERROR_SERIES,INSTRUMENTS,P);
                results(6).A = xx1;
                results(6).B = xx2;
                
                  gamapre=elasticities(ERROR_SERIES1,p,xx1.alfa_brk1);
                gamapost=elasticities(ERROR_SERIES2,p,xx1.alfa_brk2);
                gama(6).pre=[gamapre(1,2) gamapre(1,3) gamapre(2,3)];
                gama(6).post=[gamapost(1,2) gamapost(1,3) gamapost(2,3)];
                      deltaf(6).pre=partial_effects(ERROR_SERIES1,REALIZED_SERIES1,p,xx1.alfa_brk1);
      deltaf(6).post=partial_effects(ERROR_SERIES2,REALIZED_SERIES2,p,xx1.alfa_brk2);
 clearvars -global -except ERROR_SERIES INSTRUMENTS REALIZED_SERIES P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
          
%****************
% Volcker
BRT=find(dummies_rec(:,2),1)-1;  %NEED THE CORRECT BRT
PiSB=BRT/T;
ERROR_SERIES1=ERROR_SERIES(1:BRT,:);
ERROR_SERIES2=ERROR_SERIES(BRT+1:T,:);
INSTRUMENTS1=INSTRUMENTS(1:BRT,:);
INSTRUMENTS2=INSTRUMENTS(BRT+1:T,:);
REALIZED_SERIES1=REALIZED_SERIES(1:BRT,:);
REALIZED_SERIES2=REALIZED_SERIES(BRT+1:T,:);

    disp('Volcker break')

  [xx1 xx2] = gmm_multi3ikTest_elast(ERROR_SERIES,INSTRUMENTS,P);
                results(7).A = xx1;
                results(7).B = xx2;
                  gamapre=elasticities(ERROR_SERIES1,p,xx1.alfa_brk1);
                gamapost=elasticities(ERROR_SERIES2,p,xx1.alfa_brk2);
                gama(7).pre=[gamapre(1,2) gamapre(1,3) gamapre(2,3)];
                gama(7).post=[gamapost(1,2) gamapost(1,3) gamapost(2,3)];
                      deltaf(7).pre=partial_effects(ERROR_SERIES1,REALIZED_SERIES1,p,xx1.alfa_brk1);
      deltaf(7).post=partial_effects(ERROR_SERIES2,REALIZED_SERIES2,p,xx1.alfa_brk2);
 clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
           
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Post-Volcker only

ERROR_SERIES=fDATA.e(dummies(:,2)==1,:);
INSTRUMENTS=X(dummies(:,2)==1,:);
REALIZED_SERIES=fDATA.r(dummies(:,2)==1,:);
dummies_pv=dummies(dummies(:,2)==1,:);
T=size(ERROR_SERIES,1);
disp ('Post-Volcker Only')

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 std_err(4).s=xx2;

 %****************
% Great Moderation

BRT=find(dummies_pv(:,3),1)-1;  %NEED THE CORRECT BRT
PiSB=BRT/T;
ERROR_SERIES1=ERROR_SERIES(1:BRT,:);
ERROR_SERIES2=ERROR_SERIES(BRT+1:T,:);
INSTRUMENTS1=INSTRUMENTS(1:BRT,:);
INSTRUMENTS2=INSTRUMENTS(BRT+1:T,:);
REALIZED_SERIES1=REALIZED_SERIES(1:BRT,:);
REALIZED_SERIES2=REALIZED_SERIES(BRT+1:T,:);

    disp('Great Moderation')

   
  [xx1 xx2] = gmm_multi3ikTest_elast(ERROR_SERIES,INSTRUMENTS,P);
                results(8).A = xx1;
                results(8).B = xx2;
                  gamapre=elasticities(ERROR_SERIES1,p,xx1.alfa_brk1);
                gamapost=elasticities(ERROR_SERIES2,p,xx1.alfa_brk2);
                gama(8).pre=[gamapre(1,2) gamapre(1,3) gamapre(2,3)];
                gama(8).post=[gamapost(1,2) gamapost(1,3) gamapost(2,3)];
                      deltaf(8).pre=partial_effects(ERROR_SERIES1,REALIZED_SERIES1,p,xx1.alfa_brk1);
      deltaf(8).post=partial_effects(ERROR_SERIES2,REALIZED_SERIES2,p,xx1.alfa_brk2);
 clearvars -global -except P
global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Pre-Volcker only
ERROR_SERIES=fDATA.e(dummies(:,2)~=1,:);
INSTRUMENTS=X(dummies(:,2)~=1,:);
REALIZED_SERIES=fDATA.r(dummies(:,2)~=1,:);
T=size(ERROR_SERIES,1);
disp ('Pre-Volcker Only')

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
res_smp(1).j=xx1; 
std_err(5).s=xx2;
 
  clearvars -global -except P
global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %% Post-GM only

ERROR_SERIES=fDATA.e(dummies(:,3)==1,:);
INSTRUMENTS=X(dummies(:,3)==1,:);
REALIZED_SERIES=fDATA.r(dummies(:,3)~=1,:);
T=size(ERROR_SERIES,1);
disp ('Post-GM Only')

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 res_smp(2).j=xx1;
 std_err(6).s=xx2;

  clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %% Pre-GM only

ERROR_SERIES=fDATA.e(dummies(:,3)~=1,:);
INSTRUMENTS=X(dummies(:,3)~=1,:);
REALIZED_SERIES=fDATA.r(dummies(:,3)~=1,:);
T=size(ERROR_SERIES,1);
disp ('Pre-GM Only')

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 res_smp(3).j=xx1;
 std_err(7).s=xx2;
 
clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Expansions Subsample: 

ERROR_SERIES_EXP=fDATA.e(dummies(:,1)~=1,:);
INSTRUMENTS_EXP=X(dummies(:,1)~=1,:);
REALIZED_SERIES_EXP=fDATA.r(dummies(:,1)~=1,:);
dummies_exp=dummies(dummies(:,1)~=1,:);
%****************
%Post-GM
 disp ('Expansions Post-GM')
ERROR_SERIES=ERROR_SERIES_EXP(dummies_exp(:,3)==1,:);
INSTRUMENTS=INSTRUMENTS_EXP(dummies_exp(:,3)==1,:);
REALIZED_SERIES=REALIZED_SERIES_EXP(dummies_exp(:,3)==1,:);

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 std_err(8).s=xx2;
 
 clearvars -global -except P
global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
  %****************
 %Pre-GM
  disp ('Expansions Pre-GM')
 ERROR_SERIES=ERROR_SERIES_EXP(dummies_exp(:,3)~=1,:);
INSTRUMENTS=INSTRUMENTS_EXP(dummies_exp(:,3)~=1,:);
REALIZED_SERIES=REALIZED_SERIES_EXP(dummies_exp(:,3)~=1,:);
[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
std_err(9).s=xx2;

 clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 %****************
 %Post-Volcker
 disp ('Expansions Post-GM')
ERROR_SERIES=ERROR_SERIES_EXP(dummies_exp(:,2)==1,:);
INSTRUMENTS=INSTRUMENTS_EXP(dummies_exp(:,2)==1,:);
REALIZED_SERIES=REALIZED_SERIES_EXP(dummies_exp(:,2)==1,:);

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 std_err(10).s=xx2;
 
 clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 %****************
 %Pre-Volcker
  disp ('Expansions Pre-GM')
 ERROR_SERIES=ERROR_SERIES_EXP(dummies_exp(:,2)~=1,:);
INSTRUMENTS=INSTRUMENTS_EXP(dummies_exp(:,2)~=1,:);
REALIZED_SERIES=REALIZED_SERIES_EXP(dummies_exp(:,2)~=1,:);

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
std_err(11).s=xx2;
 clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Post-Volcker subsample

ERROR_SERIES_PV=fDATA.e(dummies(:,2)==1,:);
INSTRUMENTS_PV=X(dummies(:,2)==1,:);
REALIZED_SERIES_PV=fDATA.r(dummies(:,2)==1,:);
dummies_pv=dummies(dummies(:,2)==1,:);

%Post-GM
 disp ('Post-V Post-GM')
ERROR_SERIES=ERROR_SERIES_PV(dummies_pv(:,3)==1,:);
INSTRUMENTS=INSTRUMENTS_PV(dummies_pv(:,3)==1,:);
REALIZED_SERIES=REALIZED_SERIES_PV(dummies_pv(:,3)==1,:);
[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
 std_err(12).s=xx2;
 
 clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
  %Pre-GM
  disp ('Expansions Pre-GM')
 ERROR_SERIES=ERROR_SERIES_PV(dummies_pv(:,3)~=1,:);
INSTRUMENTS=INSTRUMENTS_PV(dummies_pv(:,3)~=1,:);
REALIZED_SERIES=REALIZED_SERIES_PV(dummies_pv(:,3)~=1,:);

[xx1 xx2] = gmm_multi3ikjc(ERROR_SERIES,INSTRUMENTS,p);
std_err(13).s=xx2;

 clearvars -global -except P
 global P ERROR_SERIES INSTRUMENTS REALIZED_SERIES PiSB BRT ERROR_SERIES1 INSTRUMENTS1 REALIZED_SERIES1 ERROR_SERIES2 INSTRUMENTS2 REALIZED_SERIES2
 
 %% Saving Results
%  
%  if data==1
%  save([savepath 'results_old'],'res_smp','std_err','results','gama','gamafull')
%  elseif data==2
%      save([savepath 'results_new'],'res_smp','std_err','results','gama','gamafull')
%  elseif data==3
%      save([savepath 'results_1217_philly'],'res_smp','std_err','results','gama','gamafull','deltaf') % Contains the new estimation of the Var-Covar Matrix
%  elseif data==4
%      save([savepath 'results_philly_1stp'],'res_smp','std_err','results','gama','gamafull')
%  elseif data==5
%      save([savepath 'results_philly_2stp'],'res_smp','std_err','results','gama','gamafull')
%  elseif data==6
%      save([savepath 'results_philly_4stp'],'res_smp','std_err','results','gama','gamafull')
%    elseif data==7
%      save([savepath 'results_philly_1st_release'],'res_smp','std_err','results','gama','gamafull')
%  end
%  
 end