%******************
% Code to generate Figures 1.a-1.b of
% "Assymmetry, Complementarities, and State Dependence in Federal Reserve
% Forecasts"
% Caunedo, DiCecio, Komunjer, Owyang 2018
% 
%******************

clear all
close all

[x,y]=meshgrid(-1:.01:1, -1:.01:1);

tau1    =   [0 0];
tau2    =   [0.4 -0.3];
tau3    =   [-0.5 0];
tau4    =   [0.7 -0.5]; 

z1ns    =   x.^2+y.^2+(x.*tau1(1)+y.*tau1(2)).*(x.^2+y.^2).^(1/2);
z2ns    =   x.^2+y.^2+(x.*tau2(1)+y.*tau2(2)).*(x.^2+y.^2).^(1/2);
z3ns    =   x.^2+y.^2+(x.*tau3(1)+y.*tau3(2)).*(x.^2+y.^2).^(1/2);
z4ns    =   x.^2+y.^2+(x.*tau4(1)+y.*tau4(2)).*(x.^2+y.^2).^(1/2);


z1s     =   (x.^2)+x.*abs(x).*tau1(1)+(y.^2)+y.*abs(y).*tau1(2);
z2s     =   (x.^2)+x.*abs(x).*tau2(1)+(y.^2)+y.*abs(y).*tau2(2);
z3s     =   (x.^2)+x.*abs(x).*tau3(1)+(y.^2)+y.*abs(y).*tau3(2);   
z4s     =   (x.^2)+x.*abs(x).*tau4(1)+(y.^2)+y.*abs(y).*tau4(2);
% Separable Loss

fig1    =   figure;
sub1    =	subplot(2,2,1,'Parent',fig1,'PlotBoxAspectRatio',[1 1 1],'Layer','top',...
    'FontSize',16,'FontName','Times New Roman');
box(sub1,'on');
grid(sub1,'on');
hold(sub1,'all');
contour(x,y,z1s,10,'-k','Parent',sub1,'LineWidth',2);
title('{\bf\tau} = (\tau_{1}, \tau_{2}) = (0,0)','FontSize',16,'FontName','Times New Roman')
xlabel('e_{1}','FontSize',16,'FontName','Times New Roman')
ylabel('e_{2}','FontSize',16,'FontName','Times New Roman')

sub2    =	subplot(2,2,2,'Parent',fig1,'PlotBoxAspectRatio',[1 1 1],'Layer','top',...
    'FontSize',16,'FontName','Times New Roman');
box(sub2,'on');
grid(sub2,'on');
hold(sub2,'all');
contour(x,y,z2s,10,'-k','Parent',sub2,'LineWidth',2);
title('{\bf\tau} = (\tau_{1}, \tau_{2}) = (0.4,-0.3)','FontSize',16,'FontName','Times New Roman')
xlabel('e_{1}','FontSize',16,'FontName','Times New Roman')
ylabel('e_{2}','FontSize',16,'FontName','Times New Roman')


sub3    =	subplot(2,2,3,'Parent',fig1,'PlotBoxAspectRatio',[1 1 1],'Layer','top',...
    'FontSize',16,'FontName','Times New Roman');
box(sub3,'on');
grid(sub3,'on');
hold(sub3,'all');
contour(x,y,z3s,10,'-k','Parent',sub3,'LineWidth',2);
title('{\bf\tau} = (\tau_{1}, \tau_{2}) = [-0.5,0]','FontSize',16,'FontName','Times New Roman')
xlabel('e_{1}','FontSize',16,'FontName','Times New Roman')
ylabel('e_{2}','FontSize',16,'FontName','Times New Roman')

sub4    =	subplot(2,2,4,'Parent',fig1,'PlotBoxAspectRatio',[1 1 1],'Layer','top',...
    'FontSize',16,'FontName','Times New Roman');
box(sub4,'on');
grid(sub4,'on');
hold(sub4,'all');
contour(x,y,z4s,10,'-k','Parent',sub4,'LineWidth',2);
title('{\bf\tau} = (\tau_{1}, \tau_{2}) = (0.7,-0.5)','FontSize',16,'FontName','Times New Roman')
xlabel('e_{1}','FontSize',16,'FontName','Times New Roman')
ylabel('e_{2}','FontSize',16,'FontName','Times New Roman')

print -depsc fig1_s


% Non-separable Loss

fig2    =   figure;
sub1    =	subplot(2,2,1,'Parent',fig2,'PlotBoxAspectRatio',[1 1 1],'Layer','top',...
    'FontSize',16,'FontName','Times New Roman');
box(sub1,'on');
grid(sub1,'on');
hold(sub1,'all');
contour(x,y,z1ns,10,'-k','Parent',sub1,'LineWidth',2);
title('{\bf\tau} = (\tau_{1}, \tau_{2}) = (0,0)','FontSize',16,'FontName','Times New Roman')
xlabel('e_{1}','FontSize',16,'FontName','Times New Roman')
ylabel('e_{2}','FontSize',16,'FontName','Times New Roman')

sub2    =	subplot(2,2,2,'Parent',fig2,'PlotBoxAspectRatio',[1 1 1],'Layer','top',...
    'FontSize',16,'FontName','Times New Roman');
box(sub2,'on');
grid(sub2,'on');
hold(sub2,'all');
contour(x,y,z2ns,10,'-k','Parent',sub2,'LineWidth',2);
title('{\bf\tau} = (\tau_{1}, \tau_{2}) = (0.4,-0.3)','FontSize',16,'FontName','Times New Roman')
xlabel('e_{1}','FontSize',16,'FontName','Times New Roman')
ylabel('e_{2}','FontSize',16,'FontName','Times New Roman')

sub3    =	subplot(2,2,3,'Parent',fig2,'PlotBoxAspectRatio',[1 1 1],'Layer','top',...
    'FontSize',16,'FontName','Times New Roman');
box(sub3,'on');
grid(sub3,'on');
hold(sub3,'all');
contour(x,y,z3ns,10,'-k','Parent',sub3,'LineWidth',2);
title('{\bf\tau} = (\tau_{1}, \tau_{2}) = (-0.5,0)','FontSize',16,'FontName','Times New Roman')
xlabel('e_{1}','FontSize',16,'FontName','Times New Roman')
ylabel('e_{2}','FontSize',16,'FontName','Times New Roman')

sub4    =	subplot(2,2,4,'Parent',fig2,'PlotBoxAspectRatio',[1 1 1],'Layer','top',...
    'FontSize',16,'FontName','Times New Roman');
box(sub4,'on');
grid(sub4,'on');
hold(sub4,'all');
contour(x,y,z4ns,10,'-k','Parent',sub4,'LineWidth',2);
title('{\bf\tau} = (\tau_{1}, \tau_{2}) = (0.7,-0.5)','FontSize',16,'FontName','Times New Roman')
xlabel('e_{1}','FontSize',16,'FontName','Times New Roman')
ylabel('e_{2}','FontSize',16,'FontName','Times New Roman')


print -depsc fig1_ns
