function [parGMM_2Test, fGMM_2Test, retcodeGMM_2Test] = GMMmultiloss3Test(parZ0);
global P ERROR_SERIES INSTRUMENTS N_ITER WEIGHT_WT_1 WEIGHT_WT_2 PAR_N_ITER_1 PAR_N_ITER_2 WEIGHT_WT_2Test ...
    PAR_N_ITER_2Test PiSB BRT ERROR_SERIES1 INSTRUMENTS1 ERROR_SERIES2 INSTRUMENTS2 WEIGHT_WT_2SB1 WEIGHT_WT_2SB2;

% GMM_MULTI_LOSS_2.M            Version I.K. 22/12/2006
%   Constructs the GMM estimates for multivariate loss parameters in a bivariate loss:
%       L2(p,alpha,e) = 0.5*(norm(e,p)+t'*e)*norm(e,p)^(p-1)
% and a sum of univatiate losses: 
%       L1(p,alpha_1,e_1) + ... + L1(p,alpha_d,e_d) = (alpha - t.*(e < 0))'*(abs(e).^p)
% where
%   forecast error e = (e_1,...,e_d)'
%   exponent P (GLOBAL variable) is scalar AND FIXED!!!
%   asymmetry vector t = (2*alpha_1-1,...,2*alpha_d-1)'
%  
% Inputs:   ERROR_SERIES = time series of forecast error N-vectors (GLOBAL variable)
%           INSTRUMENTS = time series of K-vector instruments (GLOBAL variable)
%           par0 = (N+1)-vector of starting parameter values, par0 = (p0; alpha0)
% Output:   parGMM = (max_iter x (N+1)) matrix of GMM estimates, parGMM(n,:) = (p; alpha')'
%           fGMM = (max_iter x 1) vector of optimal values of the GMM objective function 
%           retcodeGMM = (max_iter x 1) vector of CV codes
% 
% COMMENTS:
%   We minimize the objective function Q(par,Yt) and use the notations in Hamilton, ch 14.

options = optimset('MaxIter',200,'MaxFunEvals',1000,'TolFun', 1e-6,'Display','off',...
    'LargeScale','off','GradObj','off');

% Linear inequality constraints A.x <= b on the parameters of the model
delta = 0.0001; % some small number
[T,N] = size(ERROR_SERIES);
[T1,N1]=size(ERROR_SERIES1);
[T2,N2]=size(ERROR_SERIES2);

%I NEED TO INCREASE the size of the CONSTRAINT FOR THE ADDITIONAL
%PARAMETERS OF THE BREAK

A = zeros(2*N,N);
b = [];
for i=1:1:N
    A(2*i-1,i) = 1;       % alpha_i < 1
    A(2*i,i) = -1;        % alpha_i > 0
    b = [b;[1-delta; -delta]];
end

ASB = zeros(2*N,N);
bSB = [];
for i=1:1:N
    ASB(2*i-1,i) = 1;
%     ASB(2*i-1+2*N,i+N) = 1;% alpha_i < 1
    ASB(2*i,i) = -1;
%     ASB(2*i+2*N,i+N) = -1;% alpha_i > 0
    bSB = [bSB;[1-delta; -delta]];
end
% bSB=[bSB;bSB];

% Recursive estimation 
max_iter = 50;

q = floor(1+T^0.2);    % cf Hamilton eq 14.1.19
q1= floor(1+T1^0.2);
q2= floor(1+T2^0.2);
parGMM_1 = []; fGMM_1 = []; retcodeGMM_1 = [];
parGMM_2 = []; fGMM_2 = []; retcodeGMM_2 = [];
parGMM_2Test = []; fGMM_2Test = []; retcodeGMM_2Test = [];
N_ITER = 1;
% PAR_N_ITER_1 = par0;
% PAR_N_ITER_2 = par0;
PAR_N_ITER_2Test =[parZ0;parZ0];
  
while N_ITER <= max_iter
    % Display N_ITER
    N_ITER;
    if N_ITER > 1
     
%         WEIGHT_WT_2SB1 = WeightWT_2Test(q1,PAR_N_ITER_2Test(1:N,1),1);
%         WEIGHT_WT_2SB2 = WeightWT_2Test(q2,PAR_N_ITER_2Test(N+1:2*N,1),2); 
         WEIGHT_WT_2SB1 = WeightWT_2Test(q,PAR_N_ITER_2Test(N+1:2*N,1),3);  % When the third entry is 3, I use the full sample of data to estimate the weighting matrix
         WEIGHT_WT_2SB2 = WeightWT_2Test(q,PAR_N_ITER_2Test(N+1:2*N,1),3); 
     
 
        WEIGHT_WT_2Test = kron(WEIGHT_WT_2SB1, [1 0;0 0])/PiSB+ kron(WEIGHT_WT_2SB2, [0 0;0 1])/(1-PiSB);
    end


    % multivariate loss to to estimate the parameters under H1
     [parGMM_N_ITERTest,fGMM_N_ITERTest,retcodeGMM_N_ITERTest,output_N_ITERTest,lambda_N_ITERTest,...
         grGMM_N_ITERTest,hessGMM_N_ITERTest] = ...
        fmincon(@ObjFctGMMmulti2Test1,PAR_N_ITER_2Test(1:N),ASB,bSB,[],[],[],[],[],options);
    
      PAR_N_ITER_2Test(1:N,1) = parGMM_N_ITERTest;
  
 
     [parGMM_N_ITERTest,fGMM_N_ITERTest,retcodeGMM_N_ITERTest,output_N_ITERTest,lambda_N_ITERTest,...
         grGMM_N_ITERTest,hessGMM_N_ITERTest] = ...
        fmincon(@ObjFctGMMmulti2Test2,PAR_N_ITER_2Test(N+1:2*N),ASB,bSB,[],[],[],[],[],options);
    
     PAR_N_ITER_2Test(N+1:2*N,1) = parGMM_N_ITERTest;
     
     
    parGMM_2Test = [parGMM_2Test; PAR_N_ITER_2Test'];
   
    fGMM_2Test = [fGMM_2Test; fGMM_N_ITERTest];
    retcodeGMM_2Test = [retcodeGMM_2Test; retcodeGMM_N_ITERTest];

     N_ITER = N_ITER+1;

end


