function QT = ObjFctGMMmulti2Test1(x);
global P ERROR_SERIES INSTRUMENTS N_ITER WEIGHT_WT_2Test PAR_N_ITER_2Test BRT PiSB...
    ERROR_SERIES1 INSTRUMENTS1 ERROR_SERIES2 INSTRUMENTS2  WEIGHT_WT_2SB1  WEIGHT_WT_2SB2;

% OBJ_FCT_GMM_MULTI_2.M           Version I.K. - 22/12/06
%   Constructs the objective function involved in the GMM estimation 
%   for multivariate loss parameters:
%
%       L(p,alpha,e) = 0.5*(norm(e,p)+t'*e)*norm(e,p)^(p-1)
%
% where
%   forecast error e = (e_1,...,e_d)'
%   exponent p is scalar
%   asymmetry vector t = (2*alpha_1-1,...,2*alpha_d-1)'
%  
% NOTATION (Hamilton, Ch14) & COMMENTS:
% 	x = [p, alpha_1, ..., alpha_N]'            
% 	Vt = K-VECTOR OF INSTRUMENTS with K >= N+1
% 	h(x,Vt) = []'
% 	g(x) = mean(h(x,Vt))		( eq 14.1.10 )
% 	Q(x) = g(x)'*WT*g(x)		( eq 14.1.11 )
% 	where WT = Id(rxr) at the first iteration (cf. Hamilton pg413)
% The series used in the objective function is the global variable ARMA_SERIES.
% This objective function is called several times and the weighting matrix WEIGHT_WT
% (global) changes at each iteration. The number of iterations is stored in the global
% variable N_ITER and the estimator obtained at iteration N_ITER is stored in
% the global variable PAR_N_ITER.
% BRT is the date of the brake, so pi*P-1 in the notation of 

T = size(ERROR_SERIES1,1);
N = size(ERROR_SERIES1,2);


p = P;
alpha = x(1:(N));
% alpha.s2 = x(N+1:(2*N));
tau = 2*alpha - 1;
% tau.s2 = 2*alpha.s2 - 1;
% Computing the gradient N x T matrix of the multivariate loss L(p,alpha,e) wrt e
norm_p = (sum((abs(ERROR_SERIES1)).^(p*ones(T,N)),2)).^(1/p*ones(T,1));
norm_p_pm1 = norm_p.^((p-1)*ones(T,1));
% norm_p.s2 = (sum((abs(ERROR_SERIES2)).^(p*ones(T-BRT,N)),2)).^(1/p*ones(T-BRT,1));
% norm_p_pm1.s2 = norm_p.s2.^((p-1)*ones(T-BRT,1));
nu_p = [];

% nu_p2 = [];
for i=1:1:N
    nu_p = [nu_p, (sign(ERROR_SERIES1(:,i))).*(abs(ERROR_SERIES1(:,i)).^(p-1))];
%     nu_p2 = [nu_p2, (sign(ERROR_SERIES2(:,i))).*(abs(ERROR_SERIES2(:,i)).^(p-1))];
end

grad_p = p*nu_p + norm_p_pm1*(tau')+(((p-1)*ERROR_SERIES1*tau./norm_p)*ones(1,N)).*nu_p;


% grad_p.s2 = p*nu_p2 + norm_p_pm1.s2*(tau.s2')+(((p-1)*ERROR_SERIES2*tau.s2./norm_p.s2)*ones(1,N)).*nu_p2;

% Computing the vector function h(x,Vt) 
h1 = [];
h2=[];
for i=1:1:T
    h1 = [h1; kron(grad_p(i,:),INSTRUMENTS1(i,:))];   
end
% for i=1:1:T-BRT
%     h2 = [h2; kron(grad_p.s2(i,:),INSTRUMENTS2(i,:))];   
% end

% computing the function g(x)
g.s1 = sum(h1)'/size(h1,1);
% g.s2 = sum(h2)'/size(h2,1);	
gtest=g.s1;
%[g.s1;g.s2];

% computing the weighting matrix WT 
if N_ITER == 1
   WT_2 = eye(size(gtest,1),size(gtest,1));
else
   WT_2 = WEIGHT_WT_2SB1;
end
% computing the objective function to minimize QT(x) 
QT = gtest'*WT_2*gtest;               % eq. 14.1.11 
