function QT = ObjFctGMMuni1Test2(x);
global P ERROR_SERIES INSTRUMENTS N_ITER WEIGHT_WT_1Test PAR_N_ITER_1Test BRT PiSB...
    ERROR_SERIES1 INSTRUMENTS1 ERROR_SERIES2 INSTRUMENTS2 WEIGHT_WT_1SB1  WEIGHT_WT_1SB2;


% OBJ_FCT_GMMUNI_1.M           Version I.K. - 22/12/06
%   Constructs the objective function involved in the GMM estimation 
%   for a naive loss parameters: 
%       L1(p,alpha_1,e_1) + ... + L1(p,alpha_d,e_d) = (alpha - t.*(e < 0))'*(abs(e).^p)
% where
%   forecast error e = (e_1,...,e_d)'
%   exponent p is scalar
%   asymmetry vector t = (2*alpha_1-1,...,2*alpha_d-1)'
%  
% NOTATION (Hamilton, Ch14) & COMMENTS:
% 	x = [p, alpha_1, ..., alpha_N]'            
% 	Vt = K-VECTOR OF INSTRUMENTS with K >= N+1
% 	h(x,Vt) = []'
% 	g(x) = mean(h(x,Vt))		( eq 14.1.10 )
% 	Q(x) = g(x)'*WT*g(x)		( eq 14.1.11 )
% 	where WT = Id(rxr) at the first iteration (cf. Hamilton pg413)
% The series used in the objective function is the global variable ARMA_SERIES.
% This objective function is called several times and the weighting matrix WEIGHT_WT
% (global) changes at each iteration. The number of iterations is stored in the global
% variable N_ITER and the estimator obtained at iteration N_ITER is stored in
% the global variable PAR_N_ITER.

T = size(ERROR_SERIES2,1);
N = size(ERROR_SERIES2,2);
p = P;
alpha = x(1:(N));
% alpha.s2 = x(N+1:(2*N));
tau = 2*alpha - 1;
% tau.s2 = 2*alpha.s2 - 1;
% Computing the gradient T x N matrix of the maive loss L(p,alpha,e) wrt e
grad_p= [];

for i=1:1:N
    grad_p = [grad_p, (tau(i) + sign(ERROR_SERIES2(:,i))).*(abs(ERROR_SERIES2(:,i)).^(p-1))];
%     grad_p.s2 = [grad_p.s2, (tau.s2(i) + sign(ERROR_SERIES2(:,i))).*(abs(ERROR_SERIES2(:,i)).^(p-1))];
end

% Computing the vector function h(x,Vt) 
h1 = [];

for i=1:1:T
    h1 = [h1; kron(grad_p(i,:),INSTRUMENTS2(i,:))];   
end
% for i=1:1:T-BRT
%     h2 = [h2; kron(grad_p.s2(i,:),INSTRUMENTS2(i,:))];   
% end
% computing the function g(x)
g = sum(h1)'/size(h1,1);
% g.s2 = sum(h2)'/size(h2,1);	
gtest=g;%;g.s2];
	
% computing the weighting matrix WT 
if N_ITER == 1
   WT_1 = eye(size(gtest,1),size(gtest,1));
else
   WT_1 = WEIGHT_WT_1SB2; 
end
% computing the objective function to minimize QT(x) 
QT = gtest'*WT_1*gtest;               % eq. 14.1.11 
